@@ -17,12 +17,13 @@ struct attr_list {
     CK_ATTRIBUTE_PTR attrs;
 };
 
-#define ADD_ATTR_HANDLER(t, m) { .type = t, .memtype = m }
+#define ADD_ATTR_HANDLER(t, m) { .type = t, .name = #t, .memtype = m }
 
 typedef struct attr_handler2 attr_handler2;
 struct attr_handler2 {
     CK_ATTRIBUTE_TYPE type;
     CK_BYTE memtype;
+    const char *name;
 };
 
 #define ALLOC_LEN 16
@@ -172,7 +173,7 @@ static attr_handler2 attr_handlers[] = {
     ADD_ATTR_HANDLER(CKA_TPM2_ENC_BLOB, TYPE_BYTE_HEX_STR),
 };
 
-static attr_handler2 default_handler = { .memtype = 0 };
+static attr_handler2 default_handler = { .memtype = 0, .name="UNKNOWN" };
 
 static attr_handler2 *attr_lookup(CK_ATTRIBUTE_TYPE t) {
 
@@ -200,6 +201,11 @@ bool attr_list_add_int(attr_list *l, CK_ATTRIBUTE_TYPE type, CK_ULONG value) {
     return _attr_list_add(l, type, sizeof(value), (CK_BYTE_PTR)&value, TYPE_BYTE_INT);
 }
 
+bool attr_list_add_int_seq(attr_list *l, CK_ATTRIBUTE_TYPE type, CK_BYTE_PTR value, CK_ULONG len) {
+
+    return _attr_list_add(l, type, len, value, TYPE_BYTE_INT_SEQ);
+}
+
 bool attr_list_add_bool(attr_list *l, CK_ATTRIBUTE_TYPE type, CK_BBOOL value) {
 
     return _attr_list_add(l, type, sizeof(value), &value, TYPE_BYTE_BOOL);
@@ -889,13 +895,13 @@ CK_RV rsa_gen_mechs(attr_list *new_pub_attrs, attr_list *new_priv_attrs) {
     };
 
     if (new_pub_attrs) {
-        bool r = attr_list_add_buf(new_pub_attrs, CKA_ALLOWED_MECHANISMS,
+        bool r = attr_list_add_int_seq(new_pub_attrs, CKA_ALLOWED_MECHANISMS,
                 (CK_BYTE_PTR)&t, sizeof(t));
         goto_error_false(r);
     }
 
     if (new_priv_attrs) {
-        bool r = attr_list_add_buf(new_priv_attrs, CKA_ALLOWED_MECHANISMS,
+        bool r = attr_list_add_int_seq(new_priv_attrs, CKA_ALLOWED_MECHANISMS,
             (CK_BYTE_PTR)&t, sizeof(t));
         goto_error_false(r);
     }
@@ -970,13 +976,16 @@ static CK_RV ecc_gen_mechs(attr_list *new_pub_attrs, attr_list *new_priv_attrs)
     CK_MECHANISM_TYPE t[] = {
         CKM_ECDSA,
         CKM_ECDSA_SHA1,
+        CKM_ECDSA_SHA256,
+        CKM_ECDSA_SHA384,
+        CKM_ECDSA_SHA512,
     };
 
-    bool r = attr_list_add_buf(new_pub_attrs, CKA_ALLOWED_MECHANISMS,
+    bool r = attr_list_add_int_seq(new_pub_attrs, CKA_ALLOWED_MECHANISMS,
             (CK_BYTE_PTR)&t, sizeof(t));
     goto_error_false(r);
 
-    r = attr_list_add_buf(new_priv_attrs, CKA_ALLOWED_MECHANISMS,
+    r = attr_list_add_int_seq(new_priv_attrs, CKA_ALLOWED_MECHANISMS,
             (CK_BYTE_PTR)&t, sizeof(t));
     goto_error_false(r);
 
@@ -1322,6 +1331,14 @@ CK_RV attr_list_append_entry(attr_list **attrs, CK_ATTRIBUTE_PTR untrusted_attr)
     return CKR_OK;
 }
 
+const char *attr_get_name(CK_ATTRIBUTE_TYPE t) {
+
+    attr_handler2 *attr = attr_lookup(t);
+    assert(attr);
+    assert(attr->name);
+    return attr->name;
+}
+
 #define UTILS_GENERIC_ATTR_TYPE_CONVERT(T) \
     CK_RV attr_##T(CK_ATTRIBUTE_PTR attr, T *x) { \
       assert(attr); \
