@@ -32,6 +32,7 @@
 #include "tpm.h"
 #include "twist.h"
 #include "utils.h"
+#include "typed_memory.h"
 
 #include <openssl/evp.h>
 
@@ -39,7 +40,7 @@
 #define TPM2_PKCS11_STORE_DIR "/etc/tpm2_pkcs11"
 #endif
 
-#define DB_VERSION 7
+#define DB_VERSION 8
 
 #define goto_oom(x, l) if (!x) { LOGE("oom"); goto l; }
 #define goto_error(x, l) if (x) { goto l; }
@@ -1724,7 +1725,7 @@ static CK_RV handle_AES_add_cbc_ctr_modes(tobject *tobj) {
     /* copy the old mechanism into the list and add CBC_PAD and CTR */
     CK_ULONG i;
     CK_ULONG pos = 0;
-    for (i=0; i < mech_num; i++) {
+    for (i=0; i < mech_num - 2; i++) {
         assert(a && a->pValue && a->ulValueLen);
         CK_MECHANISM_TYPE old_mech = ((CK_MECHANISM_TYPE_PTR)(a->pValue))[i];
         if (old_mech == CKM_AES_CBC_PAD ||
@@ -1874,7 +1875,7 @@ static CK_RV handle_ECDSA_5_to_6(tobject *tobj) {
     /* copy the old mechanism into the list and add CBC_PAD and CTR */
     CK_ULONG i;
     CK_ULONG pos = 0;
-    for (i=0; i < mech_num; i++) {
+    for (i=0; i < mech_num - 3; i++) {
         assert(a && a->pValue && a->ulValueLen);
         CK_MECHANISM_TYPE old_mech = ((CK_MECHANISM_TYPE_PTR)(a->pValue))[i];
         if (old_mech == CKM_ECDSA_SHA256 ||
@@ -2131,6 +2132,69 @@ error:
     return rv;
 }
 
+static CK_RV dbup_handler_from_7_to_8(sqlite3 *updb) {
+
+    /*
+     * Between version 7 and 8 of the DB the following changes need to be made:
+     *
+     * Table tobjects:
+     *
+     * The YAML attributes for a int sequence has to be a yaml sequence.
+     */
+
+
+    CK_RV rv = CKR_GENERAL_ERROR;
+    sqlite3_stmt *stmt = NULL;
+
+    int rc = sqlite3_prepare_v2(updb, "SELECT * from tobjects", -1, &stmt, 0);
+    if (rc != SQLITE_OK) {
+        LOGE("Failed to fetch data: %s", sqlite3_errmsg(updb));
+        goto error;
+    }
+
+    rc = sqlite3_step(stmt);
+    if (rc == SQLITE_DONE) {
+        goto out;
+    } else if (rc != SQLITE_ROW) {
+        LOGE("Failed to step: %s", sqlite3_errmsg(updb));
+        goto error;
+    }
+
+    while (rc == SQLITE_ROW) {
+        tobject *tobj = db_tobject_new(stmt);
+        if (!tobj) {
+            LOGE("Could not process tobjects for upgrade");
+            goto error;
+        }
+
+        /* for each tobject */
+        CK_ATTRIBUTE_PTR a = attr_get_attribute_by_type(tobj->attrs, CKA_ALLOWED_MECHANISMS);
+        CK_BYTE type = type_from_ptr(a->pValue, a->ulValueLen);
+        if (type != TYPE_BYTE_INT_SEQ) {
+            rv = _db_update_tobject_attrs(updb, tobj->id, tobj->attrs);
+        }
+
+        tobject_free(tobj);
+        if (rv != CKR_OK) {
+            goto error;
+        }
+
+        rc = sqlite3_step(stmt);
+        if (rc != SQLITE_ROW && rc != SQLITE_DONE) {
+            LOGE("Failed to fetch data: %s\n", sqlite3_errmsg(updb));
+            goto error;
+        }
+    }
+
+out:
+    rv = CKR_OK;
+
+error:
+    sqlite3_finalize(stmt);
+    return rv;
+}
+
+
 static CK_RV db_backup(sqlite3 *db, const char *dbpath, sqlite3 **updb, char **copypath) {
 
     CK_RV rv = CKR_GENERAL_ERROR;
@@ -2205,7 +2269,8 @@ static CK_RV db_update(sqlite3 **xdb, const char *dbpath, unsigned old_version,
             dbup_handler_from_3_to_4,
             dbup_handler_from_4_to_5,
             dbup_handler_from_5_to_6,
-            dbup_handler_from_6_to_7
+            dbup_handler_from_6_to_7,
+            dbup_handler_from_7_to_8
     };
 
     /*
@@ -2322,9 +2387,41 @@ static CK_RV db_create(char *path, size_t len) {
     return db_for_path(path, len, db_create_handler);
 }
 
-static FILE *take_lock(const char *path, char *lockpath) {
+DEBUG_VISIBILITY FILE *take_lock(const char *path, char *lockpath) {
 
-    unsigned l = snprintf(lockpath, PATH_MAX, "%s%s", path, ".lock");
+    unsigned l;
+
+    size_t lenv_lock = 0;
+    char *env_lock = getenv("PKCS11_SQL_LOCK");
+
+    if (env_lock && (lenv_lock = strlen(env_lock) > 0)) {
+        /*
+         * lock file shall be "PKCS11_SQL_LOCK" + '/' + path + ".lock", but
+         * path's '/' will be substituted by '_'.
+         */
+        if (env_lock[lenv_lock - 1] == '/') {
+            env_lock[lenv_lock - 1] = '\0';
+            lenv_lock--;
+        }
+        if ((lenv_lock + 1 + strlen(path) + strlen(".lock")) >= PATH_MAX) {
+            LOGE("Lock file path would be longer than PATH_MAX");
+            return NULL;
+        }
+        strncpy(lockpath, env_lock, PATH_MAX-1);
+        strcat(lockpath, "/");
+        for (size_t i = 0; path[i] && (i < PATH_MAX) && (i < strlen(path)); i++) {
+            lockpath[lenv_lock + 1 + i] = '\0';
+            if (path[i] == '/') {
+                lockpath[lenv_lock + 1 + i] = '_';
+                continue;
+            }
+            lockpath[lenv_lock + 1 + i] = path[i];
+        }
+        strcat(lockpath, ".lock");
+        l = strlen(lockpath);
+    } else {
+        l = snprintf(lockpath, PATH_MAX, "%s%s", path, ".lock");
+    }
     if (l >= PATH_MAX) {
         LOGE("Lock file path is longer than PATH_MAX");
         return NULL;
