@@ -15,6 +15,7 @@
 #include "object.h"
 #include "pkcs11.h"
 #include "session_ctx.h"
+#include "ssl_util.h"
 #include "token.h"
 #include "utils.h"
 
@@ -121,19 +122,14 @@ CK_RV tobject_get_min_buf_size(tobject *tobj, CK_MECHANISM_PTR mech, size_t *max
         }
 
         int nid = 0;
-        CK_RV rv = ec_params_to_nid(a, &nid);
+        CK_RV rv = ssl_util_params_to_nid(a, &nid);
         if (rv != CKR_OK) {
             return rv;
         }
 
         /*
-         * Math below is based off of ECDSA signature:
-         * SEQUENCE (2 elem)
-         *  INTEGER R
-         *  INTEGER S
-         *
-         *  Integers R and S are bounded by keysize in bytes, followed by their
-         *  respective headers(2bytes) followed by the SEQUENCE header(2 bytes)
+         * The signature output from a PKCS#11 ECDSA operation is the raw R,S output
+         * which is twice the size of the keysize
          */
         unsigned keysize;
 
@@ -158,21 +154,7 @@ CK_RV tobject_get_min_buf_size(tobject *tobj, CK_MECHANISM_PTR mech, size_t *max
             return CKR_CURVE_NOT_SUPPORTED;
         }
 
-        /* R and S are INTEGER objects with a header and len byte */
-        static const unsigned INT_HDR = 2U;
-        /* R and S are combined in a SEQUENCE object with a header and len byte */
-        static const unsigned SEQ_HDR = 2U;
-        /* an R or S with a high bit set needs an extra nul byte so it's not negative (twos comp)*/
-        static const unsigned EXTRA = 1U;
-
-        unsigned tmp = 0;
-        safe_add(tmp, keysize, INT_HDR);
-        safe_adde(tmp, EXTRA);
-        safe_mule(tmp, 2);
-
-        tmp += SEQ_HDR;
-
-        *maxsize = tmp;
+        *maxsize = keysize * 2;
 
         return CKR_OK;
     }
@@ -1178,8 +1160,7 @@ CK_RV object_create(session_ctx *ctx, CK_ATTRIBUTE *templ, CK_ULONG count, CK_OB
     assert(tok);
     attr_list *new_attrs = NULL;
 
-    if (key_type == CKK_RSA ||
-            clazz == CKO_PUBLIC_KEY) {
+    if (key_type == CKK_RSA && clazz == CKO_PUBLIC_KEY) {
         rv = handle_rsa_public(templ, count, &new_attrs);
     } else if (clazz == CKO_DATA) {
         rv = handle_data_object(tok, templ, count, &new_attrs);
