@@ -45,8 +45,6 @@ static inline void _str_padded_copy(CK_UTF8CHAR_PTR dst, size_t dst_len, const C
     memcpy(dst, src, src_len);
 }
 
-twist utils_hash_pass(const twist pin, const twist salt);
-
 twist aes256_gcm_decrypt(const twist key, const twist objauth);
 
 twist aes256_gcm_encrypt(twist keybin, twist plaintextbin);
@@ -76,17 +74,6 @@ static inline CK_RV utils_new_random_object_auth(twist *newauthhex) {
 CK_RV utils_ctx_unwrap_objauth(twist wrappingkey, twist objauth, twist *unwrapped_auth);
 CK_RV utils_ctx_wrap_objauth(twist wrappingkey, twist objauth, twist *wrapped_auth);
 
-/**
- * Given an attribute of CKA_EC_PARAMS returns the nid value.
- * @param ecparams
- *  The DER X9.62 parameters value
- * @param nid
- *  The nid to set
- * @return
- *  CKR_OK on success.
- */
-CK_RV ec_params_to_nid(CK_ATTRIBUTE_PTR ecparams, int *nid);
-
 /**
  * Removes a PKCS7 padding on a 16 byte block.
  * @param in
@@ -225,7 +212,6 @@ static bool _do_safe_arithmetic(void *r, BN_ULONG a, BN_ULONG b,
 #define _safe_mule(r, a) _do_safe_arithmetic(&r, r, a, \
         sizeof(r), BN_mul_word)
 #else
-#define set_safe_rc(x) /* NOP */
 #define _safe_add(r, a, b) __builtin_add_overflow(a, b, &r)
 #define _safe_adde(r, a)   __builtin_add_overflow(a, r, &r)
 #define _safe_mul(r, a, b) __builtin_mul_overflow(a, b, &r)
