@@ -760,7 +760,7 @@ static void test_rsa_pkcs_encrypt_decrypt_public_5_2_returns_good(void **state)
     assert_memory_equal(plaintext2, plaintext, sizeof(plaintext));
 }
 
-static void test_aes_big_blockboundry_buffer_encrypt_decrypt_oneshot_5_2_returns(void **state) {
+static void test_aes_big_blockboundary_buffer_encrypt_decrypt_oneshot_5_2_returns(void **state) {
 
     test_info *ti = test_info_from_state(state);
 
@@ -857,7 +857,7 @@ static void test_aes_big_blockboundry_buffer_encrypt_decrypt_oneshot_5_2_returns
  * This tests that 3 blocks of plaintext encrypted and decrypted
  * via C_EncryptUpdate and C_DecryptUpdate calls work as expected.
  */
-static void test_aes_cbc_non_block_boundry_plaintext(void **state) {
+static void test_aes_cbc_non_block_boundary_plaintext(void **state) {
 
     test_info *ti = test_info_from_state(state);
 
@@ -963,7 +963,7 @@ static void test_aes_cbc_non_block_boundry_plaintext(void **state) {
     unsigned char plaintext2[sizeof(plaintext)]= { 0 };
     unsigned long plaintext2_len = sizeof(plaintext2);
 
-    /* go one past the block boundry */
+    /* go one past the block boundary */
     rv = C_DecryptUpdate (session, ciphertext, 17,
             plaintext2, &plaintext2_len);
     assert_int_equal(rv, CKR_OK);
@@ -1013,7 +1013,7 @@ static void test_aes_cbc_non_block_boundry_plaintext(void **state) {
     assert_memory_equal(plaintext, plaintext2, sizeof(plaintext2));
 }
 
-static void test_aes_cbc_non_block_boundry_plaintext_bad(void **state) {
+static void test_aes_cbc_non_block_boundary_plaintext_bad(void **state) {
 
     test_info *ti = test_info_from_state(state);
 
@@ -1103,6 +1103,62 @@ static void test_aes_0_bytes(void **state) {
     assert_int_equal(ciphertext_len, 0);
 }
 
+static void test_aes_cbc_pad_issue730(void **state) {
+    test_info *ti = test_info_from_state(state);
+
+    CK_SESSION_HANDLE session = ti->handle;
+
+    /* init encryption */
+    CK_BYTE iv[16] = {
+        0xDE, 0xAD, 0xBE, 0xEF,
+        0xDE, 0xAD, 0xBE, 0xEF,
+        0xDE, 0xAD, 0xBE, 0xEF,
+        0xDE, 0xAD, 0xBE, 0xEF,
+    };
+
+    CK_MECHANISM mechanism = {
+        CKM_AES_CBC_PAD, iv, sizeof(iv)
+    };
+
+    CK_BYTE plaintext[17] = {
+         1,  2,  3,  4,  5,  6,  7,  8,  9, 10,
+        11, 12, 13, 14, 15, 16, 17
+    };
+
+
+    /* encrypt init */
+    CK_RV rv = C_EncryptInit(session, &mechanism, ti->objects.aes);
+    assert_int_equal(rv, CKR_OK);
+
+    unsigned long ciphertext_len = 0;
+    rv = C_Encrypt(session,
+            plaintext, sizeof(plaintext),
+            NULL, &ciphertext_len);
+    assert_int_equal(rv, CKR_OK);
+    assert_int_equal(ciphertext_len, 32);
+
+    CK_BYTE ciphertext[32] = { 0 };
+
+    rv = C_Encrypt(session,
+            plaintext, sizeof(plaintext),
+            ciphertext, &ciphertext_len);
+    assert_int_equal(rv, CKR_OK);
+    assert_int_equal(ciphertext_len, sizeof(ciphertext));
+
+    /* decrypt init */
+    rv = C_DecryptInit(session, &mechanism, ti->objects.aes);
+    assert_int_equal(rv, CKR_OK);
+
+    CK_BYTE plaintext2[sizeof(plaintext)] = { 0 };
+    unsigned long plaintext2_len = sizeof(plaintext2);
+    rv = C_Decrypt(session,
+            ciphertext, ciphertext_len,
+            plaintext2, &plaintext2_len);
+    assert_int_equal(rv, CKR_OK);
+    assert_int_equal(plaintext2_len, sizeof(plaintext2));
+    assert_memory_equal(plaintext2, plaintext, sizeof(plaintext2));
+}
+
 static void test_aes_cbc_pad_small_oneshot(void **state) {
 
     test_info *ti = test_info_from_state(state);
@@ -1253,7 +1309,7 @@ static void test_aes_cbc_pad_multiple_blocks(void **state) {
     unsigned char plaintext2[sizeof(plaintext)]= { 0 };
     unsigned long plaintext2_len = sizeof(plaintext2);
 
-    /* go one past the block boundry */
+    /* go one past the block boundary */
     rv = C_DecryptUpdate (session, ciphertext, 17,
             plaintext2, &plaintext2_len);
     assert_int_equal(rv, CKR_OK);
@@ -1440,7 +1496,7 @@ static void test_aes_cbc_pad_multiple_blocks_with_extra(void **state) {
     unsigned char plaintext2[sizeof(plaintext)]= { 0 };
     unsigned long plaintext2_len = sizeof(plaintext2);
 
-    /* go one past the block boundry */
+    /* go one past the block boundary */
     rv = C_DecryptUpdate (session, ciphertext, 17,
             plaintext2, &plaintext2_len);
     assert_int_equal(rv, CKR_OK);
@@ -1597,7 +1653,7 @@ static void test_aes_ctr_multiple_blocks(void **state) {
     unsigned char plaintext2[sizeof(plaintext)]= { 0 };
     unsigned long plaintext2_len = sizeof(plaintext2);
 
-    /* go one past the block boundry */
+    /* go one past the block boundary */
     rv = C_DecryptUpdate (session, ciphertext, 17,
             plaintext2, &plaintext2_len);
     assert_int_equal(rv, CKR_OK);
@@ -1750,18 +1806,20 @@ int main() {
                 test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_rsa_pkcs_encrypt_decrypt_public_5_2_returns_good,
                 test_setup, test_teardown),
-        cmocka_unit_test_setup_teardown(test_aes_big_blockboundry_buffer_encrypt_decrypt_oneshot_5_2_returns,
+        cmocka_unit_test_setup_teardown(test_aes_big_blockboundary_buffer_encrypt_decrypt_oneshot_5_2_returns,
                 test_setup, test_teardown),
-        cmocka_unit_test_setup_teardown(test_aes_big_blockboundry_buffer_encrypt_decrypt_oneshot_5_2_returns,
+        cmocka_unit_test_setup_teardown(test_aes_big_blockboundary_buffer_encrypt_decrypt_oneshot_5_2_returns,
                 test_setup, test_teardown),
-        cmocka_unit_test_setup_teardown(test_aes_cbc_non_block_boundry_plaintext,
+        cmocka_unit_test_setup_teardown(test_aes_cbc_non_block_boundary_plaintext,
                 test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_aes_0_bytes,
                 test_setup, test_teardown),
-        cmocka_unit_test_setup_teardown(test_aes_cbc_non_block_boundry_plaintext_bad,
+        cmocka_unit_test_setup_teardown(test_aes_cbc_non_block_boundary_plaintext_bad,
                 test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_aes_cbc_pad_small_oneshot,
                 test_setup, test_teardown),
+        cmocka_unit_test_setup_teardown(test_aes_cbc_pad_issue730,
+                test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_aes_cbc_pad_multiple_blocks,
                 test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_aes_cbc_pad_multiple_blocks_with_extra,
