@@ -396,6 +396,8 @@ static void verify_cert_attrs(CK_SESSION_HANDLE s, CK_OBJECT_HANDLE h) {
     CK_ATTRIBUTE_PTR value = NULL;
     CK_ATTRIBUTE_PTR checkvalue = NULL;
     CK_ATTRIBUTE_PTR subject = NULL;
+    CK_ATTRIBUTE_PTR issuer = NULL;
+    CK_ATTRIBUTE_PTR serial_number = NULL;
 
     CK_ULONG i = 0;
     for (i=0; i < ARRAY_LEN(attrs); i++) {
@@ -430,6 +432,12 @@ static void verify_cert_attrs(CK_SESSION_HANDLE s, CK_OBJECT_HANDLE h) {
             case CKA_SUBJECT:
                 subject = a;
                 break;
+            case CKA_ISSUER:
+                issuer = a;
+		break;
+            case CKA_SERIAL_NUMBER:
+                serial_number = a;
+		break;
             case CKA_LABEL:
                 /* a label should be set ? */
                 assert_true(a->ulValueLen > 0);
@@ -456,10 +464,6 @@ static void verify_cert_attrs(CK_SESSION_HANDLE s, CK_OBJECT_HANDLE h) {
                 // falls-thru
             case CKA_PUBLIC_KEY_INFO:
                 // falls-thru
-            case CKA_ISSUER:
-                // falls-thru
-            case CKA_SERIAL_NUMBER:
-                // falls-thru
             case CKA_START_DATE:
                 // falls-thru
             case CKA_END_DATE:
@@ -471,6 +475,8 @@ static void verify_cert_attrs(CK_SESSION_HANDLE s, CK_OBJECT_HANDLE h) {
     }
 
     assert_non_null(subject);
+    assert_non_null(issuer);
+    assert_non_null(serial_number);
 
     assert_non_null(value);
     assert_non_null(checkvalue);
@@ -543,11 +549,35 @@ static void test_all_cert_attrs(void **state) {
     }
 }
 
+static void test_set_attribute_value_multiple_okay(void **state) {
+
+    test_info *ti = test_info_from_state(state);
+
+    CK_UTF8CHAR url [] = "http://fakeurl.com";
+    CK_UTF8CHAR label[]  = "mynewkeylabel";
+    CK_ATTRIBUTE template[] = {
+      {CKA_LABEL, label, sizeof(label) - 1},
+      {CKA_URL,   url,   sizeof(url) - 1},
+    };
+
+    CK_RV rv = C_SetAttributeValue(ti->hSession, ti->hObject, template, ARRAY_LEN(template));
+    assert_int_equal(rv, CKR_OK);
+
+    memset(label, 0, sizeof(label));
+    memset(url, 0, sizeof(label));
+
+    rv = C_GetAttributeValue(ti->hSession, ti->hObject, template, ARRAY_LEN(template));
+    assert_int_equal(rv, CKR_OK);
+
+    assert_memory_equal(template[0].pValue, "mynewkeylabel", template[0].ulValueLen);
+    assert_memory_equal(template[1].pValue, "http://fakeurl.com", template[1].ulValueLen);
+}
+
 int main() {
 
     const struct CMUnitTest tests[] = {
         cmocka_unit_test_setup_teardown(test_all_cert_attrs,
-                test_setup, test_teardown),
+            test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_all_pub_ecc_obj_attrs,
                 test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_all_priv_ecc_obj_attrs,
@@ -566,6 +596,9 @@ int main() {
                 test_setup, test_teardown),
         cmocka_unit_test_setup_teardown(test_get_attribute_value_multiple_fail,
                 test_setup, test_teardown),
+        /* this must go last as it modifies the key label */
+        cmocka_unit_test_setup_teardown(test_set_attribute_value_multiple_okay,
+                test_setup, test_teardown),
     };
 
     return cmocka_run_group_tests(tests, group_setup, group_teardown);
