@@ -15,7 +15,7 @@
 #include "parser.h"
 
 /* yaml file processed with xxd -i */
-static unsigned char _attrs_yaml[] = {
+static const unsigned char _attrs_yaml[] = {
   0x2d, 0x2d, 0x2d, 0x0a, 0x21, 0x21, 0x6d, 0x61, 0x70, 0x20, 0x7b, 0x0a,
   0x20, 0x20, 0x3f, 0x20, 0x21, 0x21, 0x69, 0x6e, 0x74, 0x20, 0x22, 0x30,
   0x22, 0x0a, 0x20, 0x20, 0x3a, 0x20, 0x21, 0x21, 0x69, 0x6e, 0x74, 0x20,
@@ -82,7 +82,7 @@ static unsigned char _attrs_yaml[] = {
   0x6e, 0x74, 0x20, 0x22, 0x34, 0x31, 0x36, 0x33, 0x22, 0x2c, 0x0a, 0x20,
   0x20, 0x5d, 0x2c, 0x0a, 0x7d, 0x0a
 };
-static unsigned int _attrs_yaml_len = 774;
+static const unsigned int _attrs_yaml_len = 774;
 
 static void test_attr_parser_good(void **state) {
     (void) state;
@@ -98,14 +98,14 @@ static void test_attr_parser_good(void **state) {
     attr_list_free(attrs);
 }
 
-static unsigned char _config_yaml[] = {
+static const unsigned char _config_yaml[] = {
   0x21, 0x21, 0x6d, 0x61, 0x70, 0x20, 0x7b, 0x0a, 0x20, 0x20, 0x3f, 0x20,
   0x21, 0x21, 0x73, 0x74, 0x72, 0x20, 0x22, 0x74, 0x6f, 0x6b, 0x65, 0x6e,
   0x2d, 0x69, 0x6e, 0x69, 0x74, 0x22, 0x0a, 0x20, 0x20, 0x3a, 0x20, 0x21,
   0x21, 0x62, 0x6f, 0x6f, 0x6c, 0x20, 0x22, 0x74, 0x72, 0x75, 0x65, 0x22,
   0x2c, 0x0a, 0x7d, 0x0a, 0x0a
 };
-static unsigned int _config_yaml_len = 53;
+static const unsigned int _config_yaml_len = 53;
 
 static void test_config_parser_good(void **state) {
     (void) state;
@@ -118,7 +118,7 @@ static void test_config_parser_good(void **state) {
     assert_null(config.tcti);
 }
 
-unsigned char _home_wcrobert_empty_seq_yaml[] = {
+static const unsigned char _home_wcrobert_empty_seq_yaml[] = {
   0x21, 0x21, 0x6d, 0x61, 0x70, 0x20, 0x7b, 0x0a, 0x20, 0x20, 0x3f, 0x20,
   0x21, 0x21, 0x69, 0x6e, 0x74, 0x20, 0x22, 0x30, 0x22, 0x0a, 0x20, 0x20,
   0x3a, 0x20, 0x21, 0x21, 0x69, 0x6e, 0x74, 0x20, 0x22, 0x34, 0x22, 0x2c,
@@ -215,20 +215,20 @@ unsigned char _home_wcrobert_empty_seq_yaml[] = {
   0x20, 0x20, 0x3a, 0x20, 0x21, 0x21, 0x73, 0x65, 0x71, 0x20, 0x5b, 0x0a,
   0x20, 0x20, 0x20, 0x20, 0x21, 0x21, 0x69, 0x6e, 0x74, 0x20, 0x22, 0x34,
   0x32, 0x32, 0x36, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x5d, 0x2c, 0x0a, 0x7d,
-  0x0a, 0x22, 0x0a
+  0x0a
 };
-unsigned int _home_wcrobert_empty_seq_yaml_len = 1155;
+static const unsigned int _home_wcrobert_empty_seq_yaml_len = 1153;
 
 static void test_config_parser_empty_seq(void **state) {
     (void) state;
 
     attr_list *attrs = NULL;
 
-    bool res = parse_attributes_from_string(_attrs_yaml, _attrs_yaml_len,
+    bool res = parse_attributes_from_string(_home_wcrobert_empty_seq_yaml, _home_wcrobert_empty_seq_yaml_len,
             &attrs);
     assert_true(res);
     assert_non_null(attrs);
-    assert_int_equal(attr_list_get_count(attrs), 20);
+    assert_int_equal(attr_list_get_count(attrs), 32);
 
     attr_list_free(attrs);
 }
