@@ -22,7 +22,7 @@ from .pkcs11t import (
     CKM_ECDSA_SHA512
 )
 
-VERSION = 7
+VERSION = 8
 
 #
 # With Db() as db:
@@ -46,9 +46,12 @@ class Db(object):
             ablob = f.read()
             return sqlite3.Binary(ablob)
 
-    def gettoken(self, label):
+    def gettoken(self, label=None, id=None):
         c = self._conn.cursor()
-        c.execute("SELECT * from tokens WHERE label=?", (label, ))
+        if label != None:
+            c.execute("SELECT * from tokens WHERE label=?", (label, ))
+        elif id != None:
+            c.execute("SELECT * from tokens WHERE id=?", (id, ))
         x = c.fetchone()
         if x is None:
             sys.exit('No token labeled "%s"' % label)
@@ -106,6 +109,12 @@ class Db(object):
         x = c.fetchone()
         return x
 
+    def getpid_by_tokid(self, tokid):
+        c = self._conn.cursor()
+        c.execute("SELECT pid from tokens WHERE id=?", (tokid, ))
+        x = c.fetchone()
+        return x['pid']
+
     def rmobject(self, tid):
         c = self._conn.cursor()
         c.execute("DELETE FROM tobjects WHERE id=?", (tid, ))
@@ -385,7 +394,7 @@ class Db(object):
             hexblob = bytes.hex(blob)
 
             config = {
-                'persistent' : True,
+                'transient': False,
                 'esys-tr': hexblob
             }
 
@@ -523,6 +532,36 @@ class Db(object):
                     attrs[CKA_ALLOWED_MECHANISMS] = list(deduped_attrs)
                     Db._updatetertiary(dbbakcon, t['id'], attrs)
 
+    def _update_on_8(self, dbbakcon):
+        '''
+        Between version 7 and 8 of the DB the following changes need to be made:
+
+        Table tobjects:
+
+        The YAML attributes for a int sequence has to be a yaml sequence.
+        '''
+        import ctypes
+        import socket
+        long_size = ctypes.sizeof(ctypes.c_ulong)
+
+        c = dbbakcon.cursor()
+
+        c.execute('SELECT * from tobjects')
+        tobjs = c.fetchall()
+
+        for t in tobjs:
+            attrs = yaml.safe_load(io.StringIO(t['attrs']))
+            for attr in attrs:
+                # The allowed mechanism attribute is a buffer of hexadecimal
+                # written as a string instead of being a sequence of int
+                if attr == CKA_ALLOWED_MECHANISMS and \
+                    isinstance(attrs[attr], str):
+                        list_hexa = [socket.ntohl(int(attrs[attr][i:i+long_size], 16)) for i in range(0, len(attrs[attr]), long_size)]
+                        list_int = [int(x,16) for x in list_hexa]
+                        attrs[attr] = list_int
+
+            Db._updatetertiary(dbbakcon, t['id'], attrs)
+
     def update_db(self, old_version, new_version=VERSION):
 
         # were doing the update, so make a backup to manipulate
@@ -539,27 +578,33 @@ class Db(object):
                     REPLACE INTO schema (id, schema_version) VALUES (1, {version});
                 '''.format(version=new_version))
             dbbakcon.execute(sql)
-        finally:
-            # Close the connections
-            self._conn.commit()
-            self._conn.close()
-
+        except Exception as e:
+            # Close the connection to backup
             dbbakcon.commit()
             dbbakcon.close()
 
-            # move old db to ".old" suffix
-            olddbpath = self._path + ".old"
-            os.rename(self._path, olddbpath)
+            # unlink the backup
+            os.unlink(dbbakpath)
 
-            # move the backup to the normal dbpath
-            os.rename(dbbakpath, self._path)
+            raise e
 
-            # unlink the old
-            os.unlink(olddbpath)
+        # Close the connections
+        self._conn.commit()
+        self._conn.close()
 
-            # re-establish a connection
-            self._conn = sqlite3.connect(self._path)
-            self._conn.row_factory = sqlite3.Row
+        dbbakcon.commit()
+        dbbakcon.close()
+
+        # move old db to ".old" suffix
+        olddbpath = self._path + ".old"
+        os.rename(self._path, olddbpath)
+
+        # move the backup to the normal dbpath
+        os.rename(dbbakpath, self._path)
+
+        # re-establish a connection
+        self._conn = sqlite3.connect(self._path)
+        self._conn.row_factory = sqlite3.Row
 
     def _get_version(self):
         c = self._conn.cursor()
